@@ -1,11 +1,12 @@
 package rules
 
 import (
+	regexp "github.com/wasilibs/go-re2"
+
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
-	"regexp"
+	"github.com/zricethezav/gitleaks/v8/config"
 
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
-	"github.com/zricethezav/gitleaks/v8/config"
 )
 
 func Twilio() *config.Rule {
@@ -19,8 +20,6 @@ func Twilio() *config.Rule {
 	}
 
 	// validate
-	tps := []string{
-		"twilioAPIKey := \"SK" + secrets.NewSecret(utils.Hex("32")) + "\"",
-	}
+	tps := utils.GenerateSampleSecrets("twilio", "SK"+secrets.NewSecret(utils.Hex("32")))
 	return utils.Validate(r, tps, nil)
 }
